local beep = Resources.load_audio("synth_beep_01.ogg")
local select = Resources.load_audio("power_up_01.ogg")

function card_init(user, props)
	-- If they aren't a player then they can't use this anyway, so...
	if Player.from(user) == nil then return Action.new(user) end;
	-- No state, leave them as they are.
	local action = Action.new(user)

	-- Will never actually complete, the action will have other logic to dictate its ending, so this is just to stall.
	action:set_lockout(ActionLockout.new_sequence())

	-- 30 second timer, 1800 frames at 60 frames per second
	local timer = 1800

	local deck = user:deck_cards()

	action.on_execute_func = function(self, owner)
		-- Create a step to make the sequence lockout work like we want it to.
		local step = action:create_step()

		owner._lucky_pick_node = nil
	end

	-- Used to determine how many frames to wait before changing. Uses modulo below.
	local divisor = 10

	local index = math.random(#deck)

	local owner = nil

	local deck_card = nil

	local card = nil

	local default_height = -(user:height() * 1.2)

	local flash_name = false

	local colors = { Color.new(228, 64, 0, 255), Color.new(255, 255, 255, 255) }

	local color_index = 1

	action.on_update_func = function(self)
		-- If the owner somehow doesn't exist then uh, you know, fix that? Might be wise.
		if owner == nil then owner = self:owner() end
		-- Use modulo to determine if it's divisible by [divisor] for the check.
		if timer % divisor == 0 and flash_name ~= true then
			if owner._lucky_pick_node ~= nil then owner:sprite():remove_node(owner._lucky_pick_node) end

			Resources.play_audio(beep, AudioBehavior.NoOverlap)

			index = math.random(#deck)

			deck_card = owner:deck_card(index)

			if deck_card ~= nil then
				card = CardProperties.from_package(deck_card.package_id, deck_card.code)
				owner._lucky_pick_node = owner:sprite():create_text_node(TextStyle.new("CODE"), card.short_name)
				owner._lucky_pick_node:set_never_flip(true)
				owner._lucky_pick_node:set_offset(math.random(-8, 8), default_height + math.random(-8, 8))
				owner._lucky_pick_node:set_layer(5)
			end
		end

		if card ~= nil and owner:input_has(Input.Pressed.Use) and flash_name ~= true then
			Resources.play_audio(select)
			divisor = 10
			timer = 60
			flash_name = true
		end

		if flash_name == true and timer % divisor == 0 then
			owner._lucky_pick_node:set_color(colors[color_index])
			if color_index > 1 then color_index = 1 else color_index = color_index + 1 end
		elseif flash_name == true and timer <= 0 then
			owner._lucky_pick_node:set_visible(false)
			owner:sprite():remove_node(owner._lucky_pick_node)
			owner:insert_field_card(0, card)
			self:end_action()
		end
		timer = timer - 1
	end

	return action
end
